###############
 API Reference 
###############

The primary class that the :mod:`aspen` library provides is
:class:`~aspen.request_processor.RequestProcessor`. See
:mod:`~aspen.testing` for helpers to integrate Aspen into your framework's
testing infrastructure, and see the :mod:`~aspen.exceptions` module for all
exceptions that Aspen raises.

.. toctree::
    :maxdepth: 1

    http
    request_processor
    dispatcher
    typecasting
    simplates
    output
    testing
    exceptions
